diff --git a/src/screens/StarterPack/Wizard/index.tsx b/src/screens/StarterPack/Wizard/index.tsx
index b5e41fc82e..e8b0a35b97 100644
--- a/src/screens/StarterPack/Wizard/index.tsx
+++ b/src/screens/StarterPack/Wizard/index.tsx
@@ -173,12 +173,15 @@ function WizardInner() {
)
const rkey = new AtUri(res.uri).rkey
- navigation.replace('StarterPack', {name: currentAccount!.did, rkey})
+
+ // TODO hack?
+ setTimeout(() => {
+ navigation.replace('StarterPack', {name: currentAccount!.handle, rkey})
+ dispatch({type: 'SetProcessing', processing: false})
+ }, 1000)
} catch (e) {
- // TODO add error to state
- console.error(e)
- } finally {
- // dispatch({type: 'SetProcessing', processing: false})
+ // TODO handle the error here
+ dispatch({type: 'SetProcessing', processing: false})
}
}
@@ -234,7 +237,11 @@ function WizardInner() {
dispatch({type: 'Back'})
}
}}>
-
+